.. SPDX-FileCopyrightText: 2022 Simone Persiani <iosonopersia@gmail.com>
..
.. SPDX-License-Identifier: ISC

oc\_ocdm.counter\_handler.filesystem\_counter\_handler module
-------------------------------------------------------------

.. automodule:: oc_ocdm.counter_handler.filesystem_counter_handler
   :members:
   :undoc-members:
   :show-inheritance:
